/*=====================================================================*/
/*                                                                     */
/*  pcmhead.h                                                          */
/*                                                                     */
/*  ----------                                                         */
/*                                                                     */
/*  IBM Confidential -- (IBM Confidential Restricted when combined     */
/*                       with the aggregated OCO source modules        */
/*                       for this program)                             */
/*                                                                     */
/*  OCO Source Materials ????-???                                      */
/*  (C) Copyright International Business Machine Corp, 1992.           */
/*  All Rights Reserved                                                */
/*                                                                     */
/*  US Government Users Restricted Rights - Use, duplication, or       */
/*  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.  */
/*                                                                     */
/*  ----------                                                         */
/*                                                                     */
/*   Defines offsets into "standard" ACPA header for various fields.   */
/*                                                                     */
/*   Steven De Gennaro                                                 */
/*   October 20, 1990                                                  */
/*                                                                     */
/*=====================================================================*/

/* $Header: /u/prosser/publish/inc/RCS/pcmhead.h,v 2.3 1997/03/26 20:37:31 prosser Exp $
 *
 * $Log: pcmhead.h,v $
 * Revision 2.3  1997/03/26  20:37:31  prosser
 * Remove dpcm_decomp and dpcm_recomp prototypes.
 *
 * Revision 2.2  1997/01/13  20:03:13  jmlr
 * 8 KHz, 11 KHz, 22 KHz
 *
 * Revision 2.1  1997/01/07  23:57:11  jmlr
 * Read Cep file like Pcm file
 *
 * Revision 2.0  94/01/04  15:01:17  burn
 * Changed revision number only
 * 
 * Revision 1.9  93/09/07  17:22:03  daggett
 * PTR 925
 * Added PCM file header format for 8 bit u-law PCM.
 * 
 * Revision 1.8  93/03/20  15:13:04  meps
 * Added extern for dpcm_decomp under OS/2.
 *
 * Revision 1.7  92/12/09  22:02:42  degenn
 * Added IBM headers and rcs logging.
 *
 * Revision 1.6  92/08/24  14:04:26  degenn
 * More changes to make 11 vs. 20 vs. ?? sampling rate dynamic
 *
 * Revision 1.5  92/08/19  14:51:41  degenn
 * Added signatures for uncompressed 11, 20 and 44 kHz audio.
 *
 * Revision 1.4  92/02/12  13:43:49  meps
 * Changed typedefs to include _T.
 *
 * Revision 1.3  92/02/11  17:57:48  meps
 * Added stuff from dpcm.h that was missing.
 *
 * Revision 1.2  91/03/01  12:31:14  eddie
 * Add some declaration from pcm-ap.cc to share with rpcm.cc
 *
 * Revision 1.1  90/11/07  23:54:55  burn
 * Initial revision
 *
 */

#ifndef PCM_HEAD_H
#define PCM_HEAD_H

#define PCM_HEADER_LENGTH             26  /* Bytes in the header... 13 shorts */
#define PCM_HEADER_OFFSET_BYTE_ORDER   0  /* Offset... byte order identifier  */
#define PCM_HEADER_OFFSET_FORMAT       1  /*           uncompressed/compressed*/
#define PCM_HEADER_OFFSET_SAMPLES      2  /*           complete samples/block */
#define PCM_HEADER_OFFSET_VOLUME       3  /*           block volume           */
#define PCM_HEADER_OFFSET_ONE          4  /*           Eddie's "1"            */
#define PCM_HEADER_OFFSET_BLOCK_INDEX  5  /*           running block index    */
#define PCM_HEADER_OFFSET_END_OF_PCM   6  /*           last block mark        */
#define PCM_HEADER_OFFSET_PCM_LENGTH  11  /*           pcm bytes per block    */
#define PCM_HEADER_OFFSET_DATA_LENGTH 12  /*           data bytes per block   */

#define PCM_BYTEORDER_LOBYTE_FIRST     1  /* Native format for PS/2           */
#define PCM_BYTEORDER_HIBYTE_FIRST     2  /* Native format for RS/6000, RT    */
#define PCM_FORMAT_DPCM5               5  /* 20 kHz, delta compression        */
#define PCM_FORMAT_PCM8                8  /*  8 kHz, uncompressed             */
#define PCM_FORMAT_PCM11              11  /* 11 kHz, uncompressed             */
#define PCM_FORMAT_PCM20              20  /* 20 kHz, uncompressed             */
#define PCM_FORMAT_PCM22              22  /* 22 kHz, uncompressed             */
#define PCM_FORMAT_PCM44              44  /* 44 kHz, uncompressed             */
#define PCM_FORMAT_MULAW11           111  /* 11 kHz, 8-bit u-law              */
#define PCM_FORMAT_MULAW8            108  /*  8 kHz, 8-bit u-law              */
#define PCM_FORMAT_ALAW8             208  /*  8 kHz, 8-bit A-law              */

#define CEP_FORMAT_CEP                11  /* 11 kHz, cep                      */

#define DPCM5_SIGNATURE    "DPCM5\015\012\032"
#define PCM11_SIGNATURE    "PCM11   "
#define PCM20_SIGNATURE    "PCM20   "
#define PCM22_SIGNATURE    "PCM22   "
#define PCM44_SIGNATURE    "PCM44   "
#define MULAW11_SIGNATURE  "PCM11U  "
#define PCM8_SIGNATURE     "PCM8    "
#define MULAW8_SIGNATURE   "MULAW8  "
#define ALAW8_SIGNATURE    "ALAW8   "

#define CEP_SIGNATURE      "CEP11   "

#define DPCM_SIGNATURE_LEN  8
#define DPCM_HEADER_LEN    16

#define MAX_DPCM_COMPRESSION   4

typedef short PCM_T;
typedef char  DPCM_T;

struct dpcm_hdr {
    char           signature[DPCM_SIGNATURE_LEN];
    unsigned long  samples;
    short          highlight_base;
    short          unused;
  };


#endif
